@@ -104,7 +104,8 @@ class WindUtil:
         if wd.ErrorCode != 0: logging.error(f' wind error: {wd.ErrorCode}')
         if wd is not None and wd.ErrorCode == 0 and len(wd.Times) > 0 and len(wd.Data[0]) > 0:
             data = {'date': wd.Times}
-            for idx, field in enumerate(wd.Fields):
+            fields = wd.Codes if len(wd.Codes) > 1 else wd.Fields
+            for idx, field in enumerate(fields):
                 data[field] = wd.Data[idx]
             df = pd.DataFrame(data)
         return df
